@@ -40,6 +40,7 @@ from livekit.agents import (
     utils,
 )
 from livekit.agents.metrics import RealtimeModelMetrics
+from livekit.agents.metrics.base import Metadata
 from livekit.agents.types import NOT_GIVEN, NotGivenOr
 from livekit.agents.utils import is_given
 from livekit.plugins.aws.experimental.realtime.turn_tracker import _TurnTracker
@@ -259,6 +260,14 @@ class RealtimeModel(llm.RealtimeModel):
         )
         self._sessions = weakref.WeakSet[RealtimeSession]()
 
+    @property
+    def model(self) -> str:
+        return self.model_id
+
+    @property
+    def provider(self) -> str:
+        return "Amazon"
+
     def session(self) -> RealtimeSession:
         """Return a new RealtimeSession bound to this model instance."""
         sess = RealtimeSession(self)
@@ -273,10 +282,6 @@ class RealtimeModel(llm.RealtimeModel):
         async def aclose(self) -> None:
             pass
 
-    @property
-    def model(self) -> str:
-        return self.model_id
-
 
 class RealtimeSession(  # noqa: F811
     llm.RealtimeSession[Literal["bedrock_server_event_received", "bedrock_client_event_queued"]]
@@ -871,7 +876,6 @@ class RealtimeSession(  # noqa: F811
         # Q: should we be counting per turn or utterance?
         metrics = RealtimeModelMetrics(
             label=self._realtime_model.label,
-            model=self._realtime_model.model,
             # TODO: pass in the correct request_id
             request_id=event_data["event"]["usageEvent"]["completionId"],
             timestamp=time.monotonic(),
@@ -898,6 +902,9 @@ class RealtimeSession(  # noqa: F811
                 audio_tokens=output_tokens["speechTokens"],
                 image_tokens=0,
             ),
+            metadata=Metadata(
+                model_name=self._realtime_model.model, model_provider=self._realtime_model.provider
+            ),
         )
         self.emit("metrics_collected", metrics)
 
